/*
 *  ILMediaManager.h
 *  iTunesInfo
 *
 *  Created by Dave Jewell on 12/05/2008.
 *  Copyright 2008 Dave Jewell. All rights reserved.
 *
 */

#import <Cocoa/Cocoa.h>
#import	"ILMediaGroup.h"

@interface ILMediaManager : NSObject
{
	ILMediaGroup *_rootMediaGroup;	// 4 = 0x4
	NSMutableArray *_mediaGroups;	// 8 = 0x8
	NSMutableArray *_mediaObjects;	// 12 = 0xc
	NSMutableDictionary *_mediaGroupsDict;	// 16 = 0x10
	NSMutableDictionary *_mediaObjectsDict;	// 20 = 0x14
	NSLock *_loadDataLock;	// 24 = 0x18
	NSLock *_replaceObjectsLock;	// 28 = 0x1c
	id _delegate;	// 32 = 0x20
	double _loadThreadPriority;	// 36 = 0x24
	BOOL _loading;	// 44 = 0x2c
	BOOL _loaded;	// 45 = 0x2d
	BOOL _needsReload;	// 46 = 0x2e
	BOOL _autoReloadEnabled;	// 47 = 0x2f
	BOOL _cancelLoadData;	// 48 = 0x30
	BOOL _loadingDisabled;	// 49 = 0x31
	NSImage *_appIcon;	// 52 = 0x34
	id _reserved1;	// 56 = 0x38
	id _reserved2;	// 60 = 0x3c
	id _reserved3;	// 64 = 0x40
}

+ (id) sharedMediaManager;
+ (void) releaseSharedMediaManager;
- (id) init;
- (void) dealloc;
- (void) reloadData;
- (void) loadData;
- (void) _unloadDataThreaded;
- (void) unloadData;	
- (BOOL) isLoading;
- (BOOL) isLoaded;
- (ILMediaGroup *) rootMediaGroup;
- (void) setRootMediaGroup: (ILMediaGroup *) group;
- (NSArray *) mediaGroups;
- (NSArray *) mediaObjects;
- (id) mediaGroupForID: (id) arg1;
- (id) mediaObjectForID: (id) arg1;
- (id) delegate;
- (void) setDelegate: (id) delegate;
- (double) loadThreadPriority;
- (void) setLoadThreadPriority: (double) value;
- (void) _loadDataThreaded;
- (void) _performLoadData;
- (BOOL) isAutoReloadEnabled;
- (void) setAutoReloadEnabled: (BOOL) autoReload;
- (void) setLoading: (BOOL) loading;
- (BOOL) needsReload;
- (void) setNeedsReload: (BOOL) value;
- (void) cancelLoadData;
- (void) setLoadingDisabled: (BOOL) loadingDisabled;
- (int) maxRating; 
- (void) updateMediaGroup: (ILMediaGroup *) group;
- (void) updateMediaGroupThreaded: (ILMediaGroup *) group;
- (void) addMediaGroup: (ILMediaGroup *) group;
- (void) addMediaGroups: (NSArray *) groups;
- (void) addMediaGroupsThreaded: (NSArray *) groups;
- (void) addMediaGroupThreaded: (ILMediaGroup *) group;
- (void) removeAllMediaGroups;
- (void) removeAllMediaGroupsThreaded;
- (void) setRootMediaGroupThreaded: (id) arg1;	
- (void) removeMediaGroup: (ILMediaGroup *) group;
- (void) removeMediaGroupThreaded: (ILMediaGroup *) group;
- (void) stopWatchingMediaGroupAndChildGroups: (ILMediaGroup *) group;
- (void) setIDsForGroups: (id) groups;
- (void) setIDsForObjects: (id) objects;
- (NSString *) uniqueID;
- (BOOL) canLoadData;
- (BOOL) appInstalled;
- (void) watchedQueryChanged: (id) arg1;
- (void) watchedQueryChanged: (id) arg1 queryScope: (id) arg2;

@end
