//
//  TunesChooser.m
//  iTunesInfo
//
//  Created by Dave Jewell on 12/05/2008.
//  Copyright 2008 Dave Jewell. All rights reserved.
//

#import "TunesChooser.h"
#import "ILMediaBrowserAudioPlayer.h"

@implementation TunesChooser

#define		DEBUG		0

#pragma mark -
#pragma mark NSTableDataSource protocol

- (int) numberOfRowsInTableView: (NSTableView *) tv
{
	if (tv == playlists) return [[tunesManager playlists] count];
	if (tv == songs) return [[selectedGroup mediaObjects] count];
	return 0;
}

- (id) tableView: (NSTableView *) tv objectValueForTableColumn: (NSTableColumn *) column row: (int) row
{
	if (tv == playlists)
	{
		ILMediaGroup * group = [[tunesManager playlists] objectAtIndex: row];
		if (DEBUG) return [NSString stringWithFormat: @"%@ (%d)", [group name], [group type]];
		else return [group name];
	}
	
	if (tv == songs)
	{
		ILMediaObject * song = [[selectedGroup mediaObjects] objectAtIndex: row];
		return [song name];
	}
	
	return @"?";
}

#pragma mark -

- (IBAction) playListClicked: (id) sender; 
{
	int row = [playlists clickedRow];
	selectedGroup = [[tunesManager playlists] objectAtIndex: row];
	[self setTitle: [selectedGroup name]];
	[songs setTarget: self];
	[songs setDoubleAction: @selector (trackClicked:)];
	[songs setDataSource: self];
	[songs reloadData];
}

- (void) initUserInterface
{
	selectedGroup = nil;
	[playlists setDataSource: self];
	[iTunesPic setImage: [tunesManager displayImage]];
}

- (void) waitForLoadCompletion: (NSTimer *) theTimer
{
	if ([tunesManager isLoaded] == YES && [tunesManager isLoading] == NO) 
	{
		[theTimer invalidate];
		// Media manager is good to go: go ahead and display data
		NSLog (@"Loaded....Song count = %d", [[tunesManager allSongs] count]);
		[self initUserInterface];
	}
}

- (void) awakeFromNib
{
	tunesManager = [ILiTunesMediaManager sharedMediaManager];
	[tunesManager loadData];
	[NSTimer scheduledTimerWithTimeInterval: 0.1 target: self selector: @selector (waitForLoadCompletion:) userInfo: nil repeats: YES];
}

- (IBAction) trackClicked: (id) sender
{
	int clickedRow = [songs clickedRow];
	if (clickedRow < [[selectedGroup mediaObjects] count])
	{
		ILMediaObject * song = [[selectedGroup mediaObjects] objectAtIndex: clickedRow];
		ILMediaBrowserAudioPlayer * player = [ILMediaBrowserAudioPlayer sharedAudioPlayer];
		[player stop: self];
		[player removeAllFiles];
		[player addAudioFile: song];
		[player	play: nil];
		[playInfo setStringValue: [NSString stringWithFormat: @"Path: %@", [song path]]];
	}
}

@end
